Module: Woods::Extractors::AstSourceExtraction

Included in:
ControllerExtractor, MailerExtractor
Defined in:
lib/woods/extractors/ast_source_extraction.rb

Overview

Shared extraction of individual method source code via the AST layer.

Included by extractors that need to pull a single method’s source from a class (e.g., ControllerExtractor, MailerExtractor).

Examples:

class FooExtractor
  include AstSourceExtraction

  def build_chunk(klass, action)
    source = extract_action_source(klass, action)
    # ...
  end
end