Exception: Woods::MCP::UnsupportedArtifact

Inherits:
BootstrapError show all
Defined in:
lib/woods/mcp/errors.rb

Overview

Raised when the schema_version in woods.json or a dump file is newer than the maximum version this gem release supports, or when the artifact header is corrupted and cannot be parsed.

Examples:

raise Woods::MCP::UnsupportedArtifact.new(
  "woods.json schema_version 3 > supported max 1",
  details: { artifact_version: 3, max_supported: 1, path: config_path.to_s }
)

Instance Attribute Summary

Attributes inherited from BootstrapError

#details

Method Summary

Methods inherited from BootstrapError

#initialize

Constructor Details

This class inherits a constructor from Woods::MCP::BootstrapError