Module: Woods::Storage::MetadataStore
- Defined in:
- lib/woods/storage/metadata_store.rb
Overview
MetadataStore provides an interface for storing and querying unit metadata.
All metadata store adapters must include the Interface module and implement its methods. The SQLite adapter is provided for local persistence.
Defined Under Namespace
Modules: Interface
Classes: InMemory, SQLite