Module: Woods::Storage::VectorStore

Defined in:
lib/woods/storage/vector_store.rb,
lib/woods/storage/qdrant.rb,
lib/woods/storage/pgvector.rb

Overview

VectorStore provides an interface for storing and searching embedding vectors.

All vector store adapters must include the Interface module and implement its methods. The InMemory adapter is provided for development and testing.

Examples:

Using the in-memory adapter

store = Woods::Storage::VectorStore::InMemory.new
store.store("User", [0.1, 0.2, 0.3], { type: "model" })
results = store.search([0.1, 0.2, 0.3], limit: 5)

Defined Under Namespace

Modules: Interface Classes: InMemory, Pgvector, Qdrant, SearchResult