Exception: Woods::MCP::ConfigMismatch
- Inherits:
-
BootstrapError
- Object
- StandardError
- Error
- BootstrapError
- Woods::MCP::ConfigMismatch
- Defined in:
- lib/woods/mcp/errors.rb
Overview
Raised when a stored config snapshot contradicts the active host config in a way that cannot be reconciled (e.g. provider class mismatch).
Instance Attribute Summary
Attributes inherited from BootstrapError
Method Summary
Methods inherited from BootstrapError
Constructor Details
This class inherits a constructor from Woods::MCP::BootstrapError