Module: Woods::Storage::GraphStore
- Defined in:
- lib/woods/storage/graph_store.rb
Overview
GraphStore provides an interface for querying code unit relationships.
All graph store adapters must include the Interface module and implement its methods. The Memory adapter wraps the existing DependencyGraph.